Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys "infomation" -> "information"



details:   https://anonhg.NetBSD.org/src/rev/ee2c8e801723
branches:  trunk
changeset: 512781:ee2c8e801723
user:      toshii <toshii%NetBSD.org@localhost>
date:      Tue Jul 17 01:37:43 2001 +0000

description:
"infomation" -> "information"

diffstat:

 sys/arch/hpc/stand/hpcboot/arm/arm.asm |   4 ++--
 sys/arch/hpcmips/dev/ite8181.c         |   4 ++--
 sys/arch/hpcmips/dev/mq200.c           |   4 ++--
 sys/arch/hpcmips/stand/pbsdboot/elf.c  |  10 +++++-----
 sys/arch/hpcmips/stand/pbsdboot/main.c |   4 ++--
 sys/arch/hpcmips/vr/rtc.c              |   4 ++--
 sys/dev/hpc/bivideo.c                  |   6 +++---
 sys/dev/hpc/hpcfb.c                    |   6 +++---
 8 files changed, 21 insertions(+), 21 deletions(-)

diffs (187 lines):

diff -r f1330daa6953 -r ee2c8e801723 sys/arch/hpc/stand/hpcboot/arm/arm.asm
--- a/sys/arch/hpc/stand/hpcboot/arm/arm.asm    Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/arch/hpc/stand/hpcboot/arm/arm.asm    Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-;      $NetBSD: arm.asm,v 1.2 2001/03/23 08:48:12 toshii Exp $ 
+;      $NetBSD: arm.asm,v 1.3 2001/07/17 01:43:42 toshii Exp $ 
 ;
 ; Copyright (c) 2001 The NetBSD Foundation, Inc.
 ; All rights reserved.
@@ -285,7 +285,7 @@
        
        ; FlatJump (kaddr_t bootinfo, kaddr_t pvec, kaddr_t stack
        ;               kaddr_t jump)
-       ;       bootinfo        boot infomation block address.
+       ;       bootinfo        boot information block address.
        ;       pvec            page vector of kernel.
        ;       stack           physical address of stack
        ;       jump            physical address of boot function 
diff -r f1330daa6953 -r ee2c8e801723 sys/arch/hpcmips/dev/ite8181.c
--- a/sys/arch/hpcmips/dev/ite8181.c    Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/arch/hpcmips/dev/ite8181.c    Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ite8181.c,v 1.12 2001/06/11 09:36:44 sato Exp $        */
+/*     $NetBSD: ite8181.c,v 1.13 2001/07/17 01:41:38 toshii Exp $      */
 
 /*-
  * Copyright (c) 2000,2001 SATO Kazumi
@@ -520,7 +520,7 @@
            bootinfo->fb_line_bytes == 0 ||
            bootinfo->fb_width == 0 ||
            bootinfo->fb_height == 0) {
-               printf("no frame buffer infomation.\n");
+               printf("no frame buffer information.\n");
                return (-1);
        }
 
diff -r f1330daa6953 -r ee2c8e801723 sys/arch/hpcmips/dev/mq200.c
--- a/sys/arch/hpcmips/dev/mq200.c      Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/arch/hpcmips/dev/mq200.c      Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mq200.c,v 1.15 2001/06/11 09:21:15 sato Exp $  */
+/*     $NetBSD: mq200.c,v 1.16 2001/07/17 01:41:38 toshii Exp $        */
 
 /*-
  * Copyright (c) 2000, 2001 TAKEMURA Shin
@@ -327,7 +327,7 @@
            bootinfo->fb_line_bytes == 0 ||
            bootinfo->fb_width == 0 ||
            bootinfo->fb_height == 0) {
-               printf("no frame buffer infomation.\n");
+               printf("no frame buffer information.\n");
                return (-1);
        }
 
diff -r f1330daa6953 -r ee2c8e801723 sys/arch/hpcmips/stand/pbsdboot/main.c
--- a/sys/arch/hpcmips/stand/pbsdboot/main.c    Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/arch/hpcmips/stand/pbsdboot/main.c    Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: main.c,v 1.57 2001/05/12 10:08:59 takemura Exp $       */
+/*     $NetBSD: main.c,v 1.58 2001/07/17 01:41:39 toshii Exp $ */
 
 /*-
  * Copyright (c) 1999, 2000 Shin Takemura.
@@ -1201,7 +1201,7 @@
                        bi.fb_type = reverse_fb_type(bi.fb_type);
                }
                /* 
-               * Set system infomation
+               * Set system information
                */
                platid.dw.dw0 = bi.platid_cpu;
                platid.dw.dw1 = bi.platid_machine;
diff -r f1330daa6953 -r ee2c8e801723 sys/arch/hpcmips/vr/rtc.c
--- a/sys/arch/hpcmips/vr/rtc.c Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/arch/hpcmips/vr/rtc.c Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: rtc.c,v 1.5 2001/05/17 05:25:32 enami Exp $    */
+/*     $NetBSD: rtc.c,v 1.6 2001/07/17 01:41:39 toshii Exp $   */
 
 /*-
  * Copyright (c) 1999 Shin Takemura. All rights reserved.
@@ -54,7 +54,7 @@
 
 /*
  * for debugging definitions
- *     VRRTCDEBUG      print rtc debugging infomation
+ *     VRRTCDEBUG      print rtc debugging information
  *     VRRTC_HEARTBEAT print HEARTBEAT (too many print...)
  */
 #ifdef VRRTCDEBUG
diff -r f1330daa6953 -r ee2c8e801723 sys/dev/hpc/bivideo.c
--- a/sys/dev/hpc/bivideo.c     Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/dev/hpc/bivideo.c     Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: bivideo.c,v 1.9 2001/07/07 09:19:39 toshii Exp $       */
+/*     $NetBSD: bivideo.c,v 1.10 2001/07/17 01:37:43 toshii Exp $      */
 
 /*-
  * Copyright (c) 1999-2001
@@ -37,7 +37,7 @@
 static const char _copyright[] __attribute__ ((unused)) =
     "Copyright (c) 1999 Shin Takemura.  All rights reserved.";
 static const char _rcsid[] __attribute__ ((unused)) =
-    "$NetBSD: bivideo.c,v 1.9 2001/07/07 09:19:39 toshii Exp $";
+    "$NetBSD: bivideo.c,v 1.10 2001/07/17 01:37:43 toshii Exp $";
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -215,7 +215,7 @@
            bootinfo->fb_line_bytes == 0 ||
            bootinfo->fb_width == 0 ||
            bootinfo->fb_height == 0) {
-               printf("no frame buffer infomation.\n");
+               printf("no frame buffer information.\n");
                return (-1);
        }
 
diff -r f1330daa6953 -r ee2c8e801723 sys/dev/hpc/hpcfb.c
--- a/sys/dev/hpc/hpcfb.c       Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/dev/hpc/hpcfb.c       Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: hpcfb.c,v 1.8 2001/07/13 10:23:41 sato Exp $   */
+/*     $NetBSD: hpcfb.c,v 1.9 2001/07/17 01:37:44 toshii Exp $ */
 
 /*-
  * Copyright (c) 1999
@@ -46,7 +46,7 @@
 static const char _copyright[] __attribute__ ((unused)) =
     "Copyright (c) 1999 Shin Takemura.  All rights reserved.";
 static const char _rcsid[] __attribute__ ((unused)) =
-    "$NetBSD: hpcfb.c,v 1.8 2001/07/13 10:23:41 sato Exp $";
+    "$NetBSD: hpcfb.c,v 1.9 2001/07/17 01:37:44 toshii Exp $";
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -113,7 +113,7 @@
 };
 
 struct hpcfb_devconfig {
-       struct rasops_info      dc_rinfo;       /* rasops infomation */
+       struct rasops_info      dc_rinfo;       /* rasops information */
 
        int             dc_blanked;     /* currently had video disabled */
        struct hpcfb_softc *dc_sc;



Home | Main Index | Thread Index | Old Index
diff -r f1330daa6953 -r ee2c8e801723 sys/arch/hpcmips/stand/pbsdboot/elf.c
--- a/sys/arch/hpcmips/stand/pbsdboot/elf.c     Tue Jul 17 00:33:04 2001 +0000
+++ b/sys/arch/hpcmips/stand/pbsdboot/elf.c     Tue Jul 17 01:37:43 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: elf.c,v 1.4 2000/01/16 03:07:32 takemura Exp $ */
+/*     $NetBSD: elf.c,v 1.5 2001/07/17 01:41:39 toshii Exp $   */
 
 /*-
  * Copyright (c) 1999 Shin Takemura.
@@ -238,7 +238,7 @@
        if (pref.load_debug_info) {
                /*
                 *  scan section header table
                 *  to search for debuging infomation
                 */
                sh_symidx = -1;
                sh_stridx = -1;
@@ -252,7 +252,7 @@
                        }
                }
                if (sh_symidx == -1 || sh_stridx == -1) {
-                       debug_printf(TEXT("debuging infomation not found\n"));
+                       debug_printf(TEXT("debuging information not found\n"));
                } else
                if (load) {
                        Elf_Ehdr dbg_eh;
@@ -332,13 +332,13 @@
                        }
                } else {
                        /*
                         *  make space for debuging infomation
                         */
                        int dbg_info_size = ROUNDUP(dbg_hdr_size +
                                                    shtbl[sh_symidx].sh_size +
                                                    shtbl[sh_stridx].sh_size,
                                                    DEBUG_INFO_ALIGN);
-                       debug_printf(TEXT("%x bytes debug infomation\n"),
+                       debug_printf(TEXT("%x bytes debug information\n"),
                                     dbg_info_size);
                        max_addr += dbg_info_size;
                        total_bytes += dbg_info_size;
@@ -238,7 +238,7 @@
                /*
                 *  scan section header table
-                *  to search for debuging infomation
+                *  to search for debuging information
                 */
                sh_symidx = -1;
@@ -332,13 +332,13 @@
                } else {
                        /*
-                        *  make space for debuging infomation
+                        *  make space for debuging information
                         */
                        int dbg_info_size = ROUNDUP(dbg_hdr_size +